@@ -55,6 +55,14 @@ class Session:
 
         return results
 
+    def execute_query(self, command):
+        """ execute one line sql commands 
+        
+            args:
+                command ---- a one line sql query 
+        """
+        return self.conn.execute(alc.sql.text(command))
+        
     def insert(self, table, columns, rows, overwrite):
         """ insert given rows into given table.
             Creates table if it doesn't already exist.
@@ -195,6 +203,12 @@ class Session:
         # return results
         return self.conn.execute(query).fetchall()
 
+    def rename_table(self, old, new):
+        """Rename an existing table in the database
+        """
+        self.conn.execute(alc.sql.text('ALTER TABLE ' + old + ' RENAME TO ' + new))
+    
+
 def comp_string_to_op(string):
     """ Converts string of expression to sqlalchemy binaryexpression
     """
